@@ -14,7 +14,13 @@
 #'   defined by xmin, xmax, ymin, ymax. Grobs with a different (absolute) size
 #'   will be center-justified in that region. Inf values can be used to fill the
 #'   full plot panel
-inset <- annotation_custom <- function(grob, xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf) {
+inset <- annotation_custom <- function(
+  grob,
+  xmin = -Inf,
+  xmax = Inf,
+  ymin = -Inf,
+  ymax = Inf
+) {
   layer(
     data = NULL,
     stat = ggplot2::StatIdentity,
@@ -32,37 +38,48 @@ inset <- annotation_custom <- function(grob, xmin = -Inf, xmax = Inf, ymin = -In
 }
 
 
-GeomCustomAnn <- ggproto("GeomCustomAnn", Geom,
+GeomCustomAnn <- ggproto(
+  "GeomCustomAnn",
+  Geom,
   extra_params = "",
   handle_na = function(data, params) {
     data
   },
 
-  draw_panel = function(data, panel_scales, coord, grob, xmin, xmax,
-                        ymin, ymax) {
-#     if (!inherits(coord, "CoordCartesian")) {
-#       stop("annotation_custom only works with Cartesian coordinates",
-#         call. = FALSE)
-#     }
+  draw_panel = function(
+    data,
+    panel_scales,
+    coord,
+    grob,
+    xmin,
+    xmax,
+    ymin,
+    ymax
+  ) {
+    #     if (!inherits(coord, "CoordCartesian")) {
+    #       stop("annotation_custom only works with Cartesian coordinates",
+    #         call. = FALSE)
+    #     }
     corners <- data.frame(x = c(xmin, xmax), y = c(ymin, ymax))
     data <- coord$transform(corners, panel_scales)
 
     x_rng <- range(data$x, na.rm = TRUE)
     y_rng <- range(data$y, na.rm = TRUE)
 
-    vp <- viewport(x = mean(x_rng), y = mean(y_rng),
-                   width = diff(x_rng), height = diff(y_rng),
-                   just = c("center","center"))
+    vp <- viewport(
+      x = mean(x_rng),
+      y = mean(y_rng),
+      width = diff(x_rng),
+      height = diff(y_rng),
+      just = c("center", "center")
+    )
     editGrob(grob, vp = vp, name = paste(grob$name, annotation_id()))
   },
 
-  default_aes = aes_(xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf)
+  default_aes = aes(xmin = -Inf, xmax = Inf, ymin = -Inf, ymax = Inf)
 )
 
 
-
-
-
 annotation_id <- local({
   i <- 1
   function() {
